==> 12.8.2.tar.gz: lib/src/models/single_component_response_of_destiny_kiosks_component.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'destiny_kiosks_component.dart';
import '../enums/component_privacy_setting.dart';

part 'single_component_response_of_destiny_kiosks_component.g.dart';

@JsonSerializable()
class SingleComponentResponseOfDestinyKiosksComponent{
	
	SingleComponentResponseOfDestinyKiosksComponent();

	factory SingleComponentResponseOfDestinyKiosksComponent.fromJson(Map<String, dynamic> json) {
		try{
			return _$SingleComponentResponseOfDestinyKiosksComponentFromJson(json);
		}catch(e){
			print(e);
		}
		return null;
	}

	/// A Kiosk is a Vendor (DestinyVendorDefinition) that sells items based on whether you have already acquired that item before.
	/// This component returns information about what Kiosk items are available to you on a *Profile* level. It is theoretically possible for Kiosks to have items gated by specific Character as well. If you ever have those, you will find them on the individual character's DestinyCharacterKiosksComponent.
	/// Note that, because this component returns vendorItemIndexes (that is to say, indexes into the Kiosk Vendor's itemList property), these results are necessarily content version dependent. Make sure that you have the latest version of the content manifest databases before using this data.
	@JsonKey(name:'data')
	DestinyKiosksComponent data;
	@JsonKey(name:'privacy',unknownEnumValue:ComponentPrivacySetting.ProtectedInvalidEnumValue)
	ComponentPrivacySetting privacy;
	/// If true, this component is disabled.
	@JsonKey(name:'disabled')
	bool disabled;

	
	
	Map<String, dynamic> toJson() => _$SingleComponentResponseOfDestinyKiosksComponentToJson(this);
}

==> 13.12.1.tar.gz: lib/src/models/single_component_response_of_destiny_kiosks_component.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'destiny_kiosks_component.dart';
import '../enums/component_privacy_setting.dart';

part 'single_component_response_of_destiny_kiosks_component.g.dart';

@JsonSerializable()
class SingleComponentResponseOfDestinyKiosksComponent{
	
	SingleComponentResponseOfDestinyKiosksComponent();

	factory SingleComponentResponseOfDestinyKiosksComponent.fromJson(Map<String, dynamic> json) {
		return _$SingleComponentResponseOfDestinyKiosksComponentFromJson(json);
	}

	/// A Kiosk is a Vendor (DestinyVendorDefinition) that sells items based on whether you have already acquired that item before.
	/// This component returns information about what Kiosk items are available to you on a *Profile* level. It is theoretically possible for Kiosks to have items gated by specific Character as well. If you ever have those, you will find them on the individual character's DestinyCharacterKiosksComponent.
	/// Note that, because this component returns vendorItemIndexes (that is to say, indexes into the Kiosk Vendor's itemList property), these results are necessarily content version dependent. Make sure that you have the latest version of the content manifest databases before using this data.
	@JsonKey(name:'data')
	DestinyKiosksComponent? data;
	@JsonKey(name:'privacy',unknownEnumValue:ComponentPrivacySetting.ProtectedInvalidEnumValue)
	ComponentPrivacySetting? privacy;
	/// If true, this component is disabled.
	@JsonKey(name:'disabled')
	bool? disabled;

	
	
	Map<String, dynamic> toJson() => _$SingleComponentResponseOfDestinyKiosksComponentToJson(this);
}
